pub enum Preprocessor {
    ExtractHeaders,
    DeleteColumnByNumber(usize),
    DeleteColumnByName(String),
    SortByColumnName(String),
    SortByColumnNumber(usize),
    DeleteRowByNumber(usize),
    DeleteRowByRegex(String),
    DeleteCellByNumber {
        column: usize,
        row: usize,
    },
    DeleteCellByName {
        column: String,
        row: usize,
    },
}
Preprocessor options

Variants



ExtractHeaders

Try to extract the headers from the first row - fallible if first row contains a number



DeleteColumnByNumber(usize)

Replace all fields in column by number by a deleted marker



DeleteColumnByName(String)

Replace all fields in column by name by a deleted marker



SortByColumnName(String)

Sort rows by column with given name. Fails if no headers were extracted or column name is not found, or if any row has no numbers there



SortByColumnNumber(usize)

Sort rows by column with given number. Fails if any row has no numbers there or if out of bounds.



DeleteRowByNumber(usize)

Replace all fields in row with given number by a deleted marker



DeleteRowByRegex(String)

Replace all fields in row where at least a single field matches regex by a deleted marker



DeleteCellByNumber

Fields

column: usize

column number

row: usize

row number

replace found cell using row and column index by a deleted marker



DeleteCellByName

Fields

column: String

column with given name

row: usize

row number

replace found cell using column header and row index by a deleted marker