Struct havocompare::csv::CSVCompareConfig
source · pub struct CSVCompareConfig {
pub delimiters: Delimiters,
pub comparison_modes: Vec<Mode>,
pub exclude_field_regex: Option<String>,
pub preprocessing: Option<Vec<Preprocessor>>,
}Expand description
Settings for the CSV comparison module
Fields
delimiters: Delimitersdelimiters for the file parsing
comparison_modes: Vec<Mode>How numerical values shall be compared, strings are always checked for identity
exclude_field_regex: Option<String>Any field matching the given regex is excluded from comparison
preprocessing: Option<Vec<Preprocessor>>Preprocessing done to the csv files before beginning the comparison